import { PluginFunction, PluginValidateFn } from '@graphql-codegen/plugin-helpers';
import { RawClientSideBasePluginConfig, ClientSideBaseVisitor, LoadedFragment, ClientSideBasePluginConfig } from '@graphql-codegen/visitor-plugin-common';
import { GraphQLSchema, OperationDefinitionNode } from 'graphql';

/**
 * @description This plugin generates [`graphql-request`](https://www.npmjs.com/package/graphql-request) ready-to-use SDK, which is fully-typed.
 */
interface RawGraphQLRequestPluginConfig extends RawClientSideBasePluginConfig {
    /**
     * @description By default the `request` method return the `data` or `errors` key from the response. If you need to access the `extensions` key you can use the `rawRequest` method.
     * @default false
     *
     * @exampleMarkdown
     * ```yml
     * generates:
     * path/to/file.ts:
     *  plugins:
     *    - typescript
     *    - typescript-operations
     *    - typescript-graphql-request
     *  config:
     *    rawRequest: true
     * ```
     */
    rawRequest?: boolean;
}

interface GraphQLRequestPluginConfig extends ClientSideBasePluginConfig {
    rawRequest: boolean;
}
declare class GraphQLRequestVisitor extends ClientSideBaseVisitor<RawGraphQLRequestPluginConfig, GraphQLRequestPluginConfig> {
    private _operationsToInclude;
    constructor(schema: GraphQLSchema, fragments: LoadedFragment[], rawConfig: RawGraphQLRequestPluginConfig);
    protected buildOperation(node: OperationDefinitionNode, documentVariableName: string, operationType: string, operationResultType: string, operationVariablesTypes: string): string;
    get sdkContent(): string;
}

declare const plugin: PluginFunction<RawGraphQLRequestPluginConfig>;
declare const validate: PluginValidateFn<any>;

export { GraphQLRequestVisitor, plugin, validate };
