"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphQLRequestVisitor = void 0;
const tslib_1 = require("tslib");
const visitor_plugin_common_1 = require("@graphql-codegen/visitor-plugin-common");
const auto_bind_1 = tslib_1.__importDefault(require("auto-bind"));
const graphql_1 = require("graphql");
const additionalExportedTypes = ``;
class GraphQLRequestVisitor extends visitor_plugin_common_1.ClientSideBaseVisitor {
    constructor(schema, fragments, rawConfig) {
        super(schema, fragments, rawConfig, {
            rawRequest: visitor_plugin_common_1.getConfigValue(rawConfig.rawRequest, false),
        });
        this._operationsToInclude = [];
        auto_bind_1.default(this);
    }
    buildOperation(node, documentVariableName, operationType, operationResultType, operationVariablesTypes) {
        this._operationsToInclude.push({
            node,
            documentVariableName,
            operationType,
            operationResultType,
            operationVariablesTypes,
        });
        return null;
    }
    get sdkContent() {
        const allPossibleActions = this._operationsToInclude
            .map(o => {
            const optionalVariables = !o.node.variableDefinitions ||
                o.node.variableDefinitions.length === 0 ||
                o.node.variableDefinitions.every(v => v.type.kind !== graphql_1.Kind.NON_NULL_TYPE || v.defaultValue);
            const doc = `${o.documentVariableName}`;
            return `${o.node.name.value}(variables${optionalVariables ? '?' : ''}: ${o.operationVariablesTypes}): Cypress.Chainable<{data: ${o.operationResultType} }> {
  return cy.gql(
    ${doc}, 
    variables,
  ).then(response => {
    expect(response.status).to.eq(200);
    return response.body as { data: ${o.operationResultType}}
  });  
}`;
        })
            .map(s => visitor_plugin_common_1.indentMultiline(s, 2));
        return `${additionalExportedTypes}
  export default {
${allPossibleActions.join(',\n')}
  };
`;
    }
}
exports.GraphQLRequestVisitor = GraphQLRequestVisitor;
//# sourceMappingURL=visitor.js.map